@@ -1,26 +1,28 @@
-from django.forms.fields import CharField
-from django.http import HttpResponse, HttpResponseRedirect
-from django.utils.translation import ugettext_lazy as _
-
+# -*- coding: utf-8 -*-
 from cms import __version__ as cms_version
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
+from cms.utils.placeholder import get_toolbar_plugin_struct
 from cms.utils.urlutils import admin_reverse
+from django.forms.fields import CharField
+from django.http import HttpResponse, HttpResponseRedirect
 
-from .settings import TEXT_CKEDITOR_CONFIGURATION
-from .widgets import TextEditorWidget
+from . import settings
+from .forms import TextForm
 from .models import Text
 from .utils import plugin_tags_to_user_html
-from .forms import TextForm
+from .widgets import TextEditorWidget
 
 
 class TextPlugin(CMSPluginBase):
     model = Text
-    name = _("Text")
+    name = settings.TEXT_PLUGIN_NAME
+    module = settings.TEXT_PLUGIN_MODULE_NAME
     form = TextForm
     render_template = "cms/plugins/text.html"
     change_form_template = "cms/plugins/text_plugin_change_form.html"
-    ckeditor_configuration = TEXT_CKEDITOR_CONFIGURATION
+    ckeditor_configuration = settings.TEXT_CKEDITOR_CONFIGURATION
+    disable_child_plugins = True
 
     def get_editor_widget(self, request, plugins, pk, placeholder, language):
         """
@@ -67,10 +69,10 @@ class TextPlugin(CMSPluginBase):
         text = Text.objects.create(
             language=request.GET['plugin_language'],
             placeholder_id=request.GET['placeholder_id'],
-            parent_id = request.GET.get(
+            parent_id=request.GET.get(
                 'plugin_parent', None
             ),
-            plugin_type='TextPlugin',
+            plugin_type=self.__class__.__name__,
             body=''
         )
         return HttpResponseRedirect(
@@ -78,9 +80,14 @@ class TextPlugin(CMSPluginBase):
         )
 
     def get_form(self, request, obj=None, **kwargs):
-        plugins = plugin_pool.get_text_enabled_plugins(
+        plugins = get_toolbar_plugin_struct(
+            plugin_pool.get_text_enabled_plugins(
+                self.placeholder.slot,
+                self.page
+            ),
             self.placeholder.slot,
-            self.page
+            self.page,
+            parent=self.__class__
         )
         pk = self.cms_plugin_instance.pk
         form = self.get_form_class(request, plugins, pk, self.cms_plugin_instance.placeholder,
@@ -110,8 +117,12 @@ class TextPlugin(CMSPluginBase):
         return context
 
     def save_model(self, request, obj, form, change):
-        obj.clean_plugins()
         super(TextPlugin, self).save_model(request, obj, form, change)
+        # This must come after calling save
+        # If `clean_plugins()` deletes child plugins, django-treebeard will call
+        # save() again on the Text instance (aka obj in this context) to update mptt values (numchild, etc).
+        # See this ticket for details https://github.com/divio/djangocms-text-ckeditor/issues/212
+        obj.clean_plugins()
 
 
 plugin_pool.register_plugin(TextPlugin)
